import { loadWasm } from "shikiji";
import { eventHandler, getQuery, lazyEventHandler } from "h3";
import { useShikiHighlighter } from "./highlighter.mjs";
import { useRuntimeConfig } from "#imports";
export default lazyEventHandler(async () => {
  const { highlight } = useRuntimeConfig().mdc;
  try {
    const wasm = await import("shikiji/onig.wasm").then((r) => r.default);
    await loadWasm(async (obj) => WebAssembly.instantiate(wasm, obj));
  } catch {
    await loadWasm({ data: await import("shikiji/wasm").then((r) => r.getWasmInlined()).then((r) => r.data) });
  }
  const shiki = useShikiHighlighter(highlight);
  return eventHandler(async (event) => {
    const { code, lang, theme: themeString, highlights: highlightsString } = getQuery(event);
    const theme = JSON.parse(themeString);
    const highlights = highlightsString ? JSON.parse(highlightsString) : void 0;
    return await shiki.getHighlightedAST(code, lang, theme, { highlights });
  });
});
